@@ -1,7 +1,7 @@
 # ============================================================
 #
 # Copyright (C) 2010 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
-#               2011 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
+# Copyright (C) 2011, 2012 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
 #
 # This file may be licensed under the terms of the
 # GNU Lesser General Public License Version 3 (the ``LGPL''),
@@ -23,6 +23,14 @@
 #
 # ============================================================
 
+"""
+This package contains a transport implementation based on the spread toolkit
+which uses a multicased-based daemon network.
+
+@author: jmoringe
+@author: jwienke
+"""
+
 import threading
 from threading import RLock
 import uuid
